package
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: Apr 19, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Debug logs at debug level
Error logs at debug level
Fatal logs at error level
Init sets up the global logger
Logger returns the global logger
Panic logs at panic level
Trace logs at trace level
type Config struct {
Level string `koanf:"level"`
Pretty bool `koanf:"pretty"`
}
Config holds logger settings
Source Files
¶
Click to show internal directories.
Click to hide internal directories.